@@ -2,7 +2,7 @@
 
 use x86_64::structures::idt::{InterruptDescriptorTable, InterruptStackFrame};
 use lazy_static::lazy_static;
-use crate::{gdt, print, println};
+use crate::{libcore::sys::gdt, print, println};
 use crate::libcore::{dev::drivers::pic8259::ChainPIC, task::kbd};
 use spin;
 
